==> component-copyable-textarea-3.3.157.tgz: package/es/CopyableTextarea.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React, { useState, useRef } from 'react';
import PropTypes from 'prop-types';
import { Trans } from '@cloudflare/intl-react';
import { Textarea as UnstyledTextarea } from '@cloudflare/component-textarea';
import { createComponent, createStyledComponent } from '@cloudflare/style-container';
const Textarea = createComponent(({
  theme
}) => ({
  height: '7rem',
  wordBreak: 'break-all',
  cursor: 'text',
  resize: 'none',
  color: theme.colors.gray[1],
  fontFamily: 'monaco, courier, monospace'
}), UnstyledTextarea);

const styles = () => ({
  mt: 3,
  cursor: 'pointer'
});

const HelpText = createComponent(({
  theme
}) => ({
  fontSize: theme.fontSizes[2],
  color: theme.colors.gray[2],
  marginTop: theme.space[2],
  marginBottom: theme.space[3]
}), 'p');

const CopyableTextarea = ({
  name,
  value = '',
  onCopy,
  className,
  clickToCopyText = 'Click here to copy',
  copiedTextToClipboardText = 'Copied text to clipboard',
  pressCommandOrCtrlCToCopyText = 'Press Command/Ctrl+C to copy',
  clickToCopyTextId = 'common.click_to_copy',
  copiedTextToClipboardTextId = 'common.copied_to_clipboard',
  pressCommandOrCtrlCToCopyTextId = 'common.copy_failed'
}) => {
  const _useState = useState('init'),
        _useState2 = _slicedToArray(_useState, 2),
        copyState = _useState2[0],
        setCopyState = _useState2[1];

  const textarea = useRef(null);
  const helpTextId = {
    init: clickToCopyTextId,
    successed: copiedTextToClipboardTextId,
    failed: pressCommandOrCtrlCToCopyTextId
  };
  const fallbackHelpText = {
    init: clickToCopyText,
    successed: copiedTextToClipboardText,
    failed: pressCommandOrCtrlCToCopyText
  };

  const handleFocus = () => {
    textarea.current && textarea.current.select();
    let success = false;

    try {
      success = document.execCommand('copy');
    } catch (err) {
      success = false;
    }

    if (success && onCopy) {
      onCopy();
    }

    setCopyState(success ? 'successed' : 'failed');
  };

  const handleBlur = () => {
    setCopyState('init');
  };

  return /*#__PURE__*/React.createElement("div", {
    className: className
  }, /*#__PURE__*/React.createElement(Textarea, {
    innerRef: textarea,
    readOnly: true,
    name: name,
    value: value,
    onFocus: handleFocus,
    onBlur: handleBlur
  }), /*#__PURE__*/React.createElement(HelpText, {
    onClick: handleFocus
  }, /*#__PURE__*/React.createElement(Trans, {
    id: helpTextId[copyState],
    _: fallbackHelpText[copyState]
  })));
};

CopyableTextarea.propTypes = {
  className: PropTypes.string,
  name: PropTypes.string.isRequired,
  value: PropTypes.string.isRequired,
  onCopy: PropTypes.func,
  clickToCopyText: PropTypes.string,
  copiedTextToClipboardText: PropTypes.string,
  pressCommandOrCtrlCToCopyText: PropTypes.string,
  clickToCopyTextId: PropTypes.string,
  copiedTextToClipboardTextId: PropTypes.string,
  pressCommandOrCtrlCToCopyTextId: PropTypes.string
};
CopyableTextarea.displayName = 'CopyableTextare';
export default createStyledComponent(styles, CopyableTextarea);

==> component-copyable-textarea-5.0.7.tgz: package/es/CopyableTextarea.js <==
import React, { useState, useRef } from 'react';
import PropTypes from 'prop-types';
import { Trans } from '@cloudflare/intl-react';
import { Textarea as UnstyledTextarea } from '@cloudflare/component-textarea';
import { createComponent, createStyledComponent } from '@cloudflare/style-container';
var Textarea = createComponent(_ref => {
  var {
    theme
  } = _ref;
  return {
    height: '7rem',
    wordBreak: 'break-all',
    cursor: 'text',
    resize: 'none',
    color: theme.colors.gray[1],
    fontFamily: 'monaco, courier, monospace'
  };
}, UnstyledTextarea);

var styles = () => ({
  mt: 3,
  cursor: 'pointer'
});

var HelpText = createComponent(_ref2 => {
  var {
    theme
  } = _ref2;
  return {
    fontSize: theme.fontSizes[2],
    color: theme.colors.gray[2],
    marginTop: theme.space[2],
    marginBottom: theme.space[3]
  };
}, 'p');

var CopyableTextarea = _ref3 => {
  var {
    name,
    value = '',
    onCopy,
    className,
    clickToCopyText = 'Click here to copy',
    copiedTextToClipboardText = 'Copied text to clipboard',
    pressCommandOrCtrlCToCopyText = 'Press Command/Ctrl+C to copy',
    clickToCopyTextId = 'common.click_to_copy',
    copiedTextToClipboardTextId = 'common.copied_to_clipboard',
    pressCommandOrCtrlCToCopyTextId = 'common.copy_failed'
  } = _ref3;
  var [copyState, setCopyState] = useState('init');
  var textarea = useRef(null);
  var helpTextId = {
    init: clickToCopyTextId,
    successed: copiedTextToClipboardTextId,
    failed: pressCommandOrCtrlCToCopyTextId
  };
  var fallbackHelpText = {
    init: clickToCopyText,
    successed: copiedTextToClipboardText,
    failed: pressCommandOrCtrlCToCopyText
  };

  var handleFocus = () => {
    textarea.current && textarea.current.select();
    var success = false;

    try {
      success = document.execCommand('copy');
    } catch (err) {
      success = false;
    }

    if (success && onCopy) {
      onCopy();
    }

    setCopyState(success ? 'successed' : 'failed');
  };

  var handleBlur = () => {
    setCopyState('init');
  };

  return /*#__PURE__*/React.createElement("div", {
    className: className
  }, /*#__PURE__*/React.createElement(Textarea, {
    innerRef: textarea,
    readOnly: true,
    name: name,
    value: value,
    onFocus: handleFocus,
    onBlur: handleBlur
  }), /*#__PURE__*/React.createElement(HelpText, {
    onClick: handleFocus
  }, /*#__PURE__*/React.createElement(Trans, {
    id: helpTextId[copyState],
    _: fallbackHelpText[copyState]
  })));
};

CopyableTextarea.propTypes = {
  className: PropTypes.string,
  name: PropTypes.string.isRequired,
  value: PropTypes.string.isRequired,
  onCopy: PropTypes.func,
  clickToCopyText: PropTypes.string,
  copiedTextToClipboardText: PropTypes.string,
  pressCommandOrCtrlCToCopyText: PropTypes.string,
  clickToCopyTextId: PropTypes.string,
  copiedTextToClipboardTextId: PropTypes.string,
  pressCommandOrCtrlCToCopyTextId: PropTypes.string
};
CopyableTextarea.displayName = 'CopyableTextare';
export default createStyledComponent(styles, CopyableTextarea);
